cmd

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: AGPL-3.0 Imports: 33 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = "3.2.0"

Version is set by ldflags at build time.

Functions

func Execute

func Execute()

Execute runs the root command.

Types

This section is empty.

Directories

Path Synopsis
exitbox-allow is a standalone binary for requesting domain access from inside an ExitBox container.
exitbox-allow is a standalone binary for requesting domain access from inside an ExitBox container.
exitbox-kv is a standalone binary for accessing a KV store from inside an ExitBox container.
exitbox-kv is a standalone binary for accessing a KV store from inside an ExitBox container.
exitbox-vault is a standalone binary for accessing vault secrets from inside an ExitBox container.
exitbox-vault is a standalone binary for accessing vault secrets from inside an ExitBox container.

Jump to