platform

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2026 License: AGPL-3.0 Imports: 1 Imported by: 0

Documentation

Overview

Package platform provides OS and architecture detection.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func DetectArch

func DetectArch() string

DetectArch returns the current architecture as a normalized string.

func DetectOS

func DetectOS() string

DetectOS returns the current operating system as a normalized string.

func GetPlatform

func GetPlatform() string

GetPlatform returns "os-arch" (e.g. "linux-x86_64").

Types

This section is empty.

Jump to