session

package
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 12, 2026 License: AGPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ListNames

func ListNames(workspaceName, agentName, projectDir string) ([]string, error)

ListNames returns all named sessions for a workspace/agent/project.

func ProjectResumeDir

func ProjectResumeDir(workspaceName, agentName, projectDir string) string

ProjectResumeDir returns the project-scoped resume directory for a workspace/agent.

func ProjectSessionsDir

func ProjectSessionsDir(workspaceName, agentName, projectDir string) string

ProjectSessionsDir returns the project-scoped sessions directory.

func RemoveByName

func RemoveByName(workspaceName, agentName, projectDir, sessionName string) (bool, error)

RemoveByName removes all stored instances of a named session. Returns true when at least one session directory was removed.

func ResolveSelector

func ResolveSelector(workspaceName, agentName, projectDir, selector string) (string, bool, error)

ResolveSelector resolves a session selector to the canonical session name. Selector may be:

  1. exact session name
  2. exact session directory key/id
  3. unique prefix of a session directory key/id

Types

This section is empty.

Jump to