Documentation
¶
Index ¶
- func ListNames(workspaceName, agentName, projectDir string) ([]string, error)
- func ProjectResumeDir(workspaceName, agentName, projectDir string) string
- func ProjectSessionsDir(workspaceName, agentName, projectDir string) string
- func RemoveByName(workspaceName, agentName, projectDir, sessionName string) (bool, error)
- func ResolveSelector(workspaceName, agentName, projectDir, selector string) (string, bool, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProjectResumeDir ¶
ProjectResumeDir returns the project-scoped resume directory for a workspace/agent.
func ProjectSessionsDir ¶
ProjectSessionsDir returns the project-scoped sessions directory.
func RemoveByName ¶
RemoveByName removes all stored instances of a named session. Returns true when at least one session directory was removed.
func ResolveSelector ¶
ResolveSelector resolves a session selector to the canonical session name. Selector may be:
- exact session name
- exact session directory key/id
- unique prefix of a session directory key/id
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.